@@ -8,7 +8,8 @@ from .. import *
 class ExampleTaskBase:
     args_class = TaskArguments
 
-    def __init__(self, taskArgs: TaskArguments = None, task_model_class=None):
+    def __init__(self, task_name, taskArgs: TaskArguments = None, task_model_class=None):
+        self._task_name = task_name
         if taskArgs is not None:
             self.task_args = taskArgs
         else:
@@ -16,7 +17,7 @@ class ExampleTaskBase:
         self._task_model_class = task_model_class
 
     def __build_task(self):
-        return TransformerTask(self.task_args, self._data_processor(),
+        return TransformerTask(self._task_name, self.task_args, self._data_processor(),
                                model_class=self._task_model_class,
                                compute_metric=self._compute_metrics)
 
@@ -40,6 +41,7 @@ class ExampleTaskBase:
     def _compute_metrics(self, p: EvalPrediction):
         preds = np.argmax(p.predictions, axis=1)
         result = self._acc_and_f1(preds, p.label_ids)
+        log.info(p)
         return result
 
     def _data_processor(self):
