@@ -14,3 +14,11 @@ class FastTaskArguments:
     model_pretrained_dir: str = field("/app/models/pretrained",
                                       "This folder is for the pretrained models downloaded from Internet.")
     model_name: str = field("bert-base-chinese", "the name of model: " + str(ALL_TASK_MODEL_PATHS))
+    train_file: str = field('train.csv', "the train data file name")
+    eval_file: str = field('dev.csv', "the eval data file name")
+    labels_file: str = field('labels.csv', "the test data file name")
+    text_col: str = field('text', '')
+    label_col: str = field('label', '')
+    batch_size_per_gpu: int = field(16, '')
+    learning_rate: float = field(5e-5, "The initial learning rate for Adam.")
+    num_train_epochs: float = field(3.0, "Total number of training epochs to perform.")
